==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/stdio/StdioSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.stdio;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

public interface StdioSpecFluent<A extends StdioSpecFluent<A>> extends Fluent<A>{


    public me.snowdrop.istio.mixer.adapter.stdio.Stream getLogStream();
    public A withLogStream(me.snowdrop.istio.mixer.adapter.stdio.Stream logStream);
    public Boolean hasLogStream();
    public Integer getMaxDaysBeforeRotation();
    public A withMaxDaysBeforeRotation(Integer maxDaysBeforeRotation);
    public Boolean hasMaxDaysBeforeRotation();
    public A withNewMaxDaysBeforeRotation(String arg1);
    public A withNewMaxDaysBeforeRotation(int arg1);
    public Integer getMaxMegabytesBeforeRotation();
    public A withMaxMegabytesBeforeRotation(Integer maxMegabytesBeforeRotation);
    public Boolean hasMaxMegabytesBeforeRotation();
    public A withNewMaxMegabytesBeforeRotation(String arg1);
    public A withNewMaxMegabytesBeforeRotation(int arg1);
    public Integer getMaxRotatedFiles();
    public A withMaxRotatedFiles(Integer maxRotatedFiles);
    public Boolean hasMaxRotatedFiles();
    public A withNewMaxRotatedFiles(String arg1);
    public A withNewMaxRotatedFiles(int arg1);
    public Level getMetricLevel();
    public A withMetricLevel(Level metricLevel);
    public Boolean hasMetricLevel();
    public Boolean isOutputAsJson();
    public A withOutputAsJson(Boolean outputAsJson);
    public Boolean hasOutputAsJson();
    public A withNewOutputAsJson(String arg1);
    public A withNewOutputAsJson(boolean arg1);
    public Level getOutputLevel();
    public A withOutputLevel(Level outputLevel);
    public Boolean hasOutputLevel();
    public String getOutputPath();
    public A withOutputPath(String outputPath);
    public Boolean hasOutputPath();
    public A addToSeverityLevels(String key,Integer value);
    public A addToSeverityLevels(Map<String,Integer> map);
    public A removeFromSeverityLevels(String key);
    public A removeFromSeverityLevels(Map<String,Integer> map);
    public Map<String,Integer> getSeverityLevels();
    public A withSeverityLevels(Map<String,Integer> severityLevels);
    public Boolean hasSeverityLevels();



}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/stdio/StdioSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.stdio;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Boolean;
import java.util.Map;

public interface StdioSpecFluent<A extends StdioSpecFluent<A>> extends Fluent<A>{


    public me.snowdrop.istio.mixer.adapter.stdio.Stream getLogStream();
    public A withLogStream(me.snowdrop.istio.mixer.adapter.stdio.Stream logStream);
    public Boolean hasLogStream();
    public Integer getMaxDaysBeforeRotation();
    public A withMaxDaysBeforeRotation(Integer maxDaysBeforeRotation);
    public Boolean hasMaxDaysBeforeRotation();
    public Integer getMaxMegabytesBeforeRotation();
    public A withMaxMegabytesBeforeRotation(Integer maxMegabytesBeforeRotation);
    public Boolean hasMaxMegabytesBeforeRotation();
    public Integer getMaxRotatedFiles();
    public A withMaxRotatedFiles(Integer maxRotatedFiles);
    public Boolean hasMaxRotatedFiles();
    public Level getMetricLevel();
    public A withMetricLevel(Level metricLevel);
    public Boolean hasMetricLevel();
    public Boolean isOutputAsJson();
    public A withOutputAsJson(Boolean outputAsJson);
    public Boolean hasOutputAsJson();
    public A withNewOutputAsJson(String arg1);
    public A withNewOutputAsJson(boolean arg1);
    public Level getOutputLevel();
    public A withOutputLevel(Level outputLevel);
    public Boolean hasOutputLevel();
    public String getOutputPath();
    public A withOutputPath(String outputPath);
    public Boolean hasOutputPath();
    public A withNewOutputPath(String arg1);
    public A withNewOutputPath(StringBuilder arg1);
    public A withNewOutputPath(StringBuffer arg1);
    public A addToSeverityLevels(String key,Integer value);
    public A addToSeverityLevels(Map<String,Integer> map);
    public A removeFromSeverityLevels(String key);
    public A removeFromSeverityLevels(Map<String,Integer> map);
    public Map<String,Integer> getSeverityLevels();
    public A withSeverityLevels(Map<String,Integer> severityLevels);
    public Boolean hasSeverityLevels();



}
